==> jgit_2.0.0.orig.tar.gz: jgit-2.0.0/org.eclipse.jgit.test/tst/org/eclipse/jgit/treewalk/filter/TreeFilterTest.java <==
/*
 * Copyright (C) 2008, Google Inc.
 * and other copyright owners as documented in the project's IP log.
 *
 * This program and the accompanying materials are made available
 * under the terms of the Eclipse Distribution License v1.0 which
 * accompanies this distribution, is reproduced below, and is
 * available at http://www.eclipse.org/org/documents/edl-v10.php
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided
 *   with the distribution.
 *
 * - Neither the name of the Eclipse Foundation, Inc. nor the
 *   names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior
 *   written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.eclipse.jgit.treewalk.filter;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertSame;
import static org.junit.Assert.assertTrue;

import org.eclipse.jgit.lib.RepositoryTestCase;
import org.eclipse.jgit.treewalk.EmptyTreeIterator;
import org.eclipse.jgit.treewalk.TreeWalk;
import org.junit.Test;

public class TreeFilterTest extends RepositoryTestCase {
	@Test
	public void testALL_IncludesAnything() throws Exception {
		final TreeWalk tw = new TreeWalk(db);
		tw.addTree(new EmptyTreeIterator());
		assertTrue(TreeFilter.ALL.include(tw));
	}

	@Test
	public void testALL_ShouldNotBeRecursive() throws Exception {
		assertFalse(TreeFilter.ALL.shouldBeRecursive());
	}

	@Test
	public void testALL_IdentityClone() throws Exception {
		assertSame(TreeFilter.ALL, TreeFilter.ALL.clone());
	}

	@Test
	public void testNotALL_IncludesNothing() throws Exception {
		final TreeWalk tw = new TreeWalk(db);
		tw.addTree(new EmptyTreeIterator());
		assertFalse(TreeFilter.ALL.negate().include(tw));
	}

	@Test
	public void testANY_DIFF_IncludesSingleTreeCase() throws Exception {
		final TreeWalk tw = new TreeWalk(db);
		tw.addTree(new EmptyTreeIterator());
		assertTrue(TreeFilter.ANY_DIFF.include(tw));
	}

	@Test
	public void testANY_DIFF_ShouldNotBeRecursive() throws Exception {
		assertFalse(TreeFilter.ANY_DIFF.shouldBeRecursive());
	}

	@Test
	public void testANY_DIFF_IdentityClone() throws Exception {
		assertSame(TreeFilter.ANY_DIFF, TreeFilter.ANY_DIFF.clone());
	}
}

==> jgit-v5.1.3.201810200350-r.tar.gz: jgit-5.1.3.201810200350-r/org.eclipse.jgit.test/tst/org/eclipse/jgit/treewalk/filter/TreeFilterTest.java <==
/*
 * Copyright (C) 2008, Google Inc.
 * and other copyright owners as documented in the project's IP log.
 *
 * This program and the accompanying materials are made available
 * under the terms of the Eclipse Distribution License v1.0 which
 * accompanies this distribution, is reproduced below, and is
 * available at http://www.eclipse.org/org/documents/edl-v10.php
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided
 *   with the distribution.
 *
 * - Neither the name of the Eclipse Foundation, Inc. nor the
 *   names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior
 *   written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.eclipse.jgit.treewalk.filter;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertSame;
import static org.junit.Assert.assertTrue;

import org.eclipse.jgit.junit.RepositoryTestCase;
import org.eclipse.jgit.treewalk.EmptyTreeIterator;
import org.eclipse.jgit.treewalk.TreeWalk;
import org.junit.Test;

public class TreeFilterTest extends RepositoryTestCase {
	@Test
	public void testALL_IncludesAnything() throws Exception {
		try (TreeWalk tw = new TreeWalk(db)) {
			tw.addTree(new EmptyTreeIterator());
			assertTrue(TreeFilter.ALL.include(tw));
		}
	}

	@Test
	public void testALL_ShouldNotBeRecursive() throws Exception {
		assertFalse(TreeFilter.ALL.shouldBeRecursive());
	}

	@Test
	public void testALL_IdentityClone() throws Exception {
		assertSame(TreeFilter.ALL, TreeFilter.ALL.clone());
	}

	@Test
	public void testNotALL_IncludesNothing() throws Exception {
		try (TreeWalk tw = new TreeWalk(db)) {
			tw.addTree(new EmptyTreeIterator());
			assertFalse(TreeFilter.ALL.negate().include(tw));
		}
	}

	@Test
	public void testANY_DIFF_IncludesSingleTreeCase() throws Exception {
		try (TreeWalk tw = new TreeWalk(db)) {
			tw.addTree(new EmptyTreeIterator());
			assertTrue(TreeFilter.ANY_DIFF.include(tw));
		}
	}

	@Test
	public void testANY_DIFF_ShouldNotBeRecursive() throws Exception {
		assertFalse(TreeFilter.ANY_DIFF.shouldBeRecursive());
	}

	@Test
	public void testANY_DIFF_IdentityClone() throws Exception {
		assertSame(TreeFilter.ANY_DIFF, TreeFilter.ANY_DIFF.clone());
	}
}
